Lua_VideoItem = class("Lua_VideoItem", Lua_ListCell);
function Lua_VideoItem:ctor(p)
    self:superCall("ctor", p, "VideoItem_skin");
end

function Lua_VideoItem:buildShowItem()
    self:superCall("buildShowItem");

    self.shareObject:SetActive(false);

    self.leftAvatar = Lua_AvatarItem.new(self.showObject);
    self.leftAvatar:setLocation(-265, 50, 0);
    self.leftAvatar:setScale(0.6, 0.6, 0.6);

    self.rightAvatar = Lua_AvatarItem.new(self.showObject);
    self.rightAvatar:setLocation(265, 50, 0);
    self.rightAvatar:setScale(0.6, 0.6, 0.6);

    self.leftForce = Lua_NumberImage.new(self.showObject);
    self.leftForce:setLocation(-295, 95, 0);
    self.leftForce.pivot = 1;
    self.leftForce.numOffsetX = -4;
    self.leftForce.numAtlas = "number";
    self.leftForce.preStr = "main_fonts_power_";

    self.rightForce = Lua_NumberImage.new(self.showObject);
    self.rightForce:setLocation(295, 95, 0);
    self.rightForce.pivot = -1;
    self.rightForce.numOffsetX = -4;
    self.rightForce.numAtlas = "number";
    self.rightForce.preStr = "main_fonts_power_";

    self.leftPanel = Lua_HeroGridViewPanel.new(self.showObject,2,0);
    self.leftPanel:setLocation(-130, -15, 0);
    self.leftPanel:setCanClick(true)

    self.rightPanel = Lua_HeroGridViewPanel.new(self.showObject,2,0);
    self.rightPanel:setLocation(130, -15, 0);
    self.rightPanel:setCanClick(true)

    self.checkFight:addClickFuntion(self, self.onCheckFight);
    self.btnShare:addClickFuntion(self, self.onShare);
    self.btnChekData:addClickFuntion(self, self.onChekData);
    self.btnCollect:addClickFuntion(self, self.onCollect);
    self.btnLike:addClickFuntion(self, self.onLike);

    self.world:addClickFuntion(self, self.onWorld);
    self.alliance:addClickFuntion(self, self.onAlliance);
    self.crossServer:addClickFuntion(self, self.onCrossServer);
end

function Lua_VideoItem:dispose()
    if self.leftAvatar ~= nil then
        self.leftAvatar:dispose();
        self.leftAvatar = nil;
    end
    if self.rightAvatar ~= nil then
        self.rightAvatar:dispose();
        self.rightAvatar = nil;
    end
    if self.leftForce ~= nil then
        self.leftForce:dispose();
        self.leftForce = nil;
    end
    if self.rightForce ~= nil then
        self.rightForce:dispose();
        self.rightForce = nil;
    end
    if self.leftPanel ~= nil then
        self.leftPanel:dispose();
        self.leftPanel = nil;
    end
    if self.rightPanel ~= nil then
        self.rightPanel:dispose();
        self.rightPanel = nil;
    end
    self.data = nil;
    self:superCall("dispose");
end

function Lua_VideoItem:setData(data)
    self.shareObject:SetActive(false);
    self.data = data;
    if data == nil then
        return;
    end

    local role = data.a_role.show_role;
    self.left_name.text = role.name;

    self.leftAvatar:setRoleId(role.id, data.a_role.is_robot);
    self.leftAvatar:setRoleDressUp(role.dress_info);
    self.leftAvatar:setRoleLevel(role.level);

    local lineup = data.a_role.lineup;
    self.leftForce.num = lineup.force;
    self.leftPanel:setRoleId(role.id, data.a_role.is_robot)
    self.leftPanel:setDataByProto(lineup.hero_list);

    role = data.d_role.show_role;
    self.right_name.text = role.name;

    self.rightAvatar:setRoleId(role.id, data.d_role.is_robot);
    self.rightAvatar:setRoleDressUp(role.dress_info);
    self.rightAvatar:setRoleLevel(role.level);

    lineup = data.d_role.lineup;
    self.rightForce.num = lineup.force;
    self.rightPanel:setRoleId(role.id, data.d_role.is_robot)
    self.rightPanel:setDataByProto(lineup.hero_list);

    if data.is_win == 1 then
        self.left_result:setAltas("iconantlas2", "Battle_widget_23");
        self.right_result:setAltas("iconantlas2", "Battle_widget_24");
    else
        self.left_result:setAltas("iconantlas2", "Battle_widget_24");
        self.right_result:setAltas("iconantlas2", "Battle_widget_23");
    end

    self.timeText.text = Lua_TimeTransform.transSeconds8(data.times);
    if data.fight_scene > 0 then
        local configInfo = DataCenter.videosUtil:getVideoConfig(data.index);
        self.stageText.text = configInfo.name.."-"..configInfo.options_des[data.fight_scene];
    else
        self.stageText.text = "";
    end

    self.playNum.text = data.replay_times;
    self.shareNum.text = data.send_times;
    self.likeNum.text = data.like_times;
    self.btnLike.mouseEnable = data.is_liked == 0;
end

function Lua_VideoItem:onCheckFight(go)
    if self.data == nil then
        return;
    end

    Lua_ProxyManager.getProxy("Lua_FightProxy"):sFightReplay(self.data.record_id, Lua_FightDefine.REPLAY_VIDEO);
end

function Lua_VideoItem:onShare(go)
    if self.data == nil then
        return;
    end
    
    self.shareObject:SetActive(true);
end

function Lua_VideoItem:onChekData(go)
    if self.data == nil then
        return;
    end
    Lua_WindowUtil.openWin("Lua_FightOverallHurtWindow", Lua_WinParam.ACTION_OPEN, self.data.hurt_collect);
end

function Lua_VideoItem:onCollect(go)
    if self.data == nil then
        return;
    end

    if self.data.is_saved == 1 then
        Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(4, self.data.record_id);
    else
        local save_times = DataCenter.videosData.save_times;
        local collect_limit = DataCenter.videosUtil:getConstConfig("self_save_limit", 1, 0);
        if save_times >= collect_limit then
            OperateAlert.show("收藏数量已经达到上限");
        else
            Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(1, self.data.record_id);
        end
    end
end

function Lua_VideoItem:onLike(go)
    if self.data == nil then
        return;
    end

    local like_times = DataCenter.videosData.like_times;
    local like_limit = DataCenter.videosUtil:getConstConfig("like_times", 1, 0);
    if like_times >= like_limit then
        OperateAlert.show("本日点赞次数已达上限");
    else
        Lua_ProxyManager.getProxy("Lua_VideosProxy"):sHandle(2, self.data.record_id);
    end
end

function Lua_VideoItem:onWorld(go)
    self:sendChat(Lua_ChatData.CHANNEL_WORLD);
    self.shareObject:SetActive(false);
end

function Lua_VideoItem:onAlliance(go)
    self:sendChat(Lua_ChatData.CHANNEL_LEAGUE);
    self.shareObject:SetActive(false);
end

function Lua_VideoItem:onCrossServer(go)
    self:sendChat(Lua_ChatData.CHANNEL_CROSS_SERVER);
    self.shareObject:SetActive(false);
end

function Lua_VideoItem:sendChat(channel)
    local configInfo = DataCenter.videosUtil:getVideoConfig(self.data.index);
    local str = LanUtil.formateStr(configInfo.share_str, self.data.a_role.show_role.name, self.data.d_role.show_role.name);
    local data = self.data.record_id;
    DataCenter.chatData:setChatShowItem(Lua_ChatData.CONTENT_FIGHT_VIDEO, data);
    Lua_ChatUtil.sendMsg(channel, str, false, true);
end