-- 录像馆
checkRequire("Lua_VideoTypeItem");
checkRequire("Lua_VideoItem");
Lua_VideosWindow = class("Lua_VideosWindow", Lua_Window);
function Lua_VideosWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_VideosWindow";
	self.skinName = "VideosWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_VideosWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.showList = DataCenter.videosUtil:getConstConfig("show_list", 3);
	self:addLuaEvent("SELECT_VIDEO_TYPE", self, self.onVideoTypeSelected);
	self:addLuaEvent("REQUEST_VIDEO_INFO", self, self.requestVideoInfo);
	self:addLuaEvent("UPDATE_VIDEO_INFO", self, self.updateVideoInfo);

	self.btnInfo = Array();
	self.btnInfo:add({ textStr = "全部录像" });
	self.btnInfo:add({ textStr = "个人记录" });
	self.btnInfo:add({ textStr = "个人收藏" });

	self.btnList = Lua_ButtonList.new(self.content, Lua_AxisDefine.Horizontal);
	self.btnList:setLocation(0, -455, 0);
	self.btnList:setButtonItem(184, 62);
	self.btnList:setClickCallBack(self, self.onButtonClick);
	self.btnList:setData(self.btnInfo);
	self.btnList:setSelected(1);

	self.cbFilterLv.selected = false;
	self.cbFilterLv:addBoxChange(self, self.onFilterChange);
end

function Lua_VideosWindow:dispose()
	self.emptyRole = nil;
	self.emptyFonts = nil;
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.menuPanel ~= nil then
		self.menuPanel:dispose();
		self.menuPanel = nil;
	end
	if self.memuArr ~= nil then
		self.memuArr:clear();
		self.memuArr = nil;
	end
	if self.typeList ~= nil then
		self.typeList:dispose();
		self.typeList = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.btnInfo ~= nil then
		self.btnInfo:clear();
		self.btnInfo = nil;
	end
	self.showList = nil;
	self:superCall("dispose");
end

function Lua_VideosWindow:onFilterChange(bSelect)
	self.cbFilterLv.selected = bSelect;
	self:requestVideoInfo();
end

function Lua_VideosWindow:onButtonClick(index)
	local param = self.showList[index];
	if type(param) == "table" then
		self.showObject:SetActive(true);
		if self.typeList == nil then
			self.typeList = Lua_DragList.new(self.showObject, 630, 54, Lua_AxisDefine.Horizontal);
			self.typeList:setLocation(0, -365, 0);
			self.typeList:setListCell(Lua_VideoTypeItem, 147, 54, 1);
		end
		self.typeList:setArrayData(param);
		self.typeList:moveToIndex(1, true);
		self.typeList:setSelected(1);
		self.typeList:setSelectClick(1)
	elseif type(param) == "number" then
		self.menuData = nil;
		self.showObject:SetActive(false);
		self:onVideoTypeSelected(param);
	end
end

function Lua_VideosWindow:onVideoTypeSelected(videoId)
	if self.videoId == videoId then
		return;
	end
	self.videoId = videoId;

	self.menuData = nil;
	self.cbFilterLv.selected = false;
	local configInfo = DataCenter.videosUtil:getVideoConfig(videoId);
	local list = configInfo.arr_value;
	if list == nil or #list <= 0 then
		self.menuData = nil;
		if self.menuPanel ~= nil then
			self.menuPanel:setEnable(false);
		end
	else
		if self.menuPanel == nil then
			self.menuPanel = Lua_DropDownMenuPanel.new(self.showObject);
			self.menuPanel:setLocation(245, 405, 0);
		end
		self.menuPanel:setEnable(true);
		
		if self.memuArr == nil then
			self.menuArr = Array();
		else
			self.menuArr:clear();
		end

		local vo;
		for i = 1, #list do
			vo = Lua_DropDownMenuVo.new();
			vo.data = list[i];
			vo.menuName = configInfo.options_des[i];
			vo.msgName = "VIDEO_DOWM_MENU";
			self.menuArr:add(vo);
		end

		local menuData = { width = 135, height = 150, menu = self.menuArr, defaultIdx = 1, msgName = "VIDEO_DOWM_MENU" };
		self.menuPanel:setData(menuData, self, self.onMenuSelected);
	end

	if self.menuArr:getSize() > 0 then
		self:onMenuSelected(self.menuArr[1].data);
	else
		self:requestVideoInfo();
	end
end

function Lua_VideosWindow:onMenuSelected(data)
	if self.menuData == data then
		return;
	end
	self.menuData = data;
	self:requestVideoInfo();
end

function Lua_VideosWindow:requestVideoInfo()
	if self.videoId == nil then
		return;
	end

	local is_filter = self.cbFilterLv.selected == true and 1 or 0
	local condition = self.menuData == nil and 0 or self.menuData
	Lua_ProxyManager.getProxy("Lua_VideosProxy"):sVideoInfo(self.videoId, is_filter, condition);
end

function Lua_VideosWindow:updateVideoInfo(msg)
	if msg == nil then
		self:checkGrideEmpty(true);
		return;
	end

	DataCenter.videosData.like_times = msg.like_times;
	DataCenter.videosData.like_rewrad_times = msg.like_rewrad_times;
	DataCenter.videosData.save_times = msg.save_times;

	local configInfo = DataCenter.videosUtil:getVideoConfig(msg.index);
	local like_limit = DataCenter.videosUtil:getConstConfig("like_times", 1, 0);
	self.likeNum.text = LanUtil.formateStr("点赞数：{1}/{2}", tostring(msg.like_times), tostring(like_limit));
	if self.videoId == 1 then -- 个人收藏
		self.likeNum:setLocation(-310, -395, 0);
		self.collectNum.text = LanUtil.formateStr("收藏数：{1}/{2}", tostring(msg.save_times), tostring(configInfo.show_limit));
	elseif self.videoId == 2 then -- 个人记录
		self.likeNum:setLocation(-310, -395, 0);
		self.collectNum.text = LanUtil.formateStr("记录自己前{1}个PVP挑战录像", tostring(configInfo.show_limit));
	else
		self.likeNum:setLocation(-310, 405, 0);
		self.collectNum.text = "";
	end

	if msg.video_list == nil or #msg.video_list <= 0 then
		if self.itemList ~= nil then
			self.itemList:setEnable(false);
		end
		self:checkGrideEmpty(true);
	else
		self:checkGrideEmpty(false);
		if self.itemList == nil then
			self.itemList = Lua_DragList.new(self.content, 625, 720, Lua_AxisDefine.Vertical);
			self.itemList:setListCell(Lua_VideoItem, 625, 400, 1);
			self.itemList:setSiblingIndex(1);
		end
		self.itemList:setEnable(true);
		if self.videoId == 1 or self.videoId == 2 then
			self.itemList:setLocation(0, 35, 0);
			self.itemList:setContentRect(625, 770);
		else
			self.itemList:setLocation(0, 27, 0);
			self.itemList:setContentRect(625, 720);
		end
		self.itemList:setArrayData(msg.video_list);
		self.itemList:moveToIndex(1, true);
	end
end

function Lua_VideosWindow:checkGrideEmpty(bShow)
	if bShow then
		if self.noneIcon == nil then
			self.noneIcon = UICreate.createUIAtlasImage(self.content, "common_altas_3", "ui_liaotian_widget_002", 0, 53, 648, 119);
		end
		self.noneIcon:setEnable(true);

		if self.noneText == nil then
			self.noneText = UICreate.createLabel(self.content, LanUtil.getValue(309000), 0, 53, 100, 40, 30);
			self.noneText.pivot = UIUtils.Pivot.Center;
			self.noneText.fontName = Lua_MyUISettings.huakangFontName;
			self.noneText.alignmentValue = 4;
			self.noneText.horizontalOverflowValue = 1;
			self.noneText.colorStr = Lua_ColorDefine.transColorStr("9F928C");
		end
		self.noneText:setEnable(true);
	else
		if self.noneIcon ~= nil then
			self.noneIcon:setEnable(false);
		end
		if self.noneText ~= nil then
			self.noneText:setEnable(false);
		end
	end
end